summaryrefslogtreecommitdiffstats
path: root/parts/classview/classtooldlg.cpp
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-14 16:45:05 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-14 16:45:05 +0000
commit48d4a26399959121f33d2bc3bfe51c7827b654fc (patch)
tree5ae5e6e00d3ba330b7b8be9bc097154b6bc739e8 /parts/classview/classtooldlg.cpp
parent7e701ace6592d09e1f2c0cf28c7d6d872d78f4f5 (diff)
downloadtdevelop-48d4a26399959121f33d2bc3bfe51c7827b654fc.tar.gz
tdevelop-48d4a26399959121f33d2bc3bfe51c7827b654fc.zip
TQt4 port kdevelop
This enables compilation under both Qt3 and Qt4 git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdevelop@1236710 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'parts/classview/classtooldlg.cpp')
-rw-r--r--parts/classview/classtooldlg.cpp70
1 files changed, 35 insertions, 35 deletions
diff --git a/parts/classview/classtooldlg.cpp b/parts/classview/classtooldlg.cpp
index df51f6f4..70e26439 100644
--- a/parts/classview/classtooldlg.cpp
+++ b/parts/classview/classtooldlg.cpp
@@ -38,40 +38,40 @@ ClassToolDialog::ClassToolDialog( ClassViewPart *part )
TQPushButton *close_button = new KPushButton(KStdGuiItem::close(), this);
- parents_button = new TQToolButton(this);
- parents_button->setPixmap( UserIcon("CTparents", KIcon::DefaultState, ClassViewFactory::instance()) );
- parents_button->setToggleButton(true);
- parents_button->setFixedSize(parents_button->sizeHint());
- TQToolTip::add(parents_button, i18n("Show parents"));
-
- children_button = new TQToolButton(this);
- children_button->setPixmap( UserIcon("CTchildren", KIcon::DefaultState, ClassViewFactory::instance()) );
- children_button->setToggleButton(true);
- children_button->setFixedSize(children_button->sizeHint());
- TQToolTip::add(children_button, i18n("Show children"));
+ tqparents_button = new TQToolButton(this);
+ tqparents_button->setPixmap( UserIcon("CTtqparents", KIcon::DefaultState, ClassViewFactory::instance()) );
+ tqparents_button->setToggleButton(true);
+ tqparents_button->setFixedSize(tqparents_button->tqsizeHint());
+ TQToolTip::add(tqparents_button, i18n("Show tqparents"));
+
+ tqchildren_button = new TQToolButton(this);
+ tqchildren_button->setPixmap( UserIcon("CTtqchildren", KIcon::DefaultState, ClassViewFactory::instance()) );
+ tqchildren_button->setToggleButton(true);
+ tqchildren_button->setFixedSize(tqchildren_button->tqsizeHint());
+ TQToolTip::add(tqchildren_button, i18n("Show tqchildren"));
clients_button = new TQToolButton(this);
clients_button->setPixmap( UserIcon("CTclients", KIcon::DefaultState, ClassViewFactory::instance()) );
clients_button->setToggleButton(true);
- clients_button->setFixedSize(clients_button->sizeHint());
+ clients_button->setFixedSize(clients_button->tqsizeHint());
TQToolTip::add(clients_button, i18n("Show clients"));
suppliers_button = new TQToolButton(this);
suppliers_button->setPixmap( UserIcon("CTsuppliers", KIcon::DefaultState, ClassViewFactory::instance()) );
suppliers_button->setToggleButton(true);
- suppliers_button->setFixedSize(suppliers_button->sizeHint());
+ suppliers_button->setFixedSize(suppliers_button->tqsizeHint());
TQToolTip::add(suppliers_button, i18n("Show suppliers"));
methods_button = new TQToolButton(this);
methods_button->setPixmap( UserIcon("CVpublic_meth", KIcon::DefaultState, ClassViewFactory::instance()) );
methods_button->setToggleButton(true);
- methods_button->setFixedSize(methods_button->sizeHint());
+ methods_button->setFixedSize(methods_button->tqsizeHint());
TQToolTip::add(methods_button, i18n("Show methods"));
attributes_button = new TQToolButton(this);
attributes_button->setPixmap( UserIcon("CVpublic_var", KIcon::DefaultState, ClassViewFactory::instance()) );
attributes_button->setToggleButton(true);
- attributes_button->setFixedSize(attributes_button->sizeHint());
+ attributes_button->setFixedSize(attributes_button->tqsizeHint());
TQToolTip::add(attributes_button, i18n("Show attributes"));
access_combo = new TQComboBox(false, this, "access combo");
@@ -86,17 +86,17 @@ ClassToolDialog::ClassToolDialog( ClassViewPart *part )
class_tree = new ClassToolWidget(part, this);
// classTree->setMinimumSize( 500, 400 );
- TQVBoxLayout *layout = new TQVBoxLayout(this, KDialog::marginHint(), KDialog::spacingHint());
+ TQVBoxLayout *tqlayout = new TQVBoxLayout(this, KDialog::marginHint(), KDialog::spacingHint());
TQHBoxLayout *firstrowLayout = new TQHBoxLayout();
TQHBoxLayout *secondrowLayout = new TQHBoxLayout();
- layout->addLayout(firstrowLayout);
- layout->addLayout(secondrowLayout);
+ tqlayout->addLayout(firstrowLayout);
+ tqlayout->addLayout(secondrowLayout);
firstrowLayout->addWidget(class_combo, 1);
firstrowLayout->addWidget(close_button, 0);
- secondrowLayout->addWidget(parents_button);
- secondrowLayout->addWidget(children_button);
+ secondrowLayout->addWidget(tqparents_button);
+ secondrowLayout->addWidget(tqchildren_button);
secondrowLayout->addWidget(clients_button);
secondrowLayout->addWidget(suppliers_button);
secondrowLayout->addStretch();
@@ -104,7 +104,7 @@ ClassToolDialog::ClassToolDialog( ClassViewPart *part )
secondrowLayout->addWidget(attributes_button);
secondrowLayout->addWidget(access_combo);
- layout->addWidget(class_tree, 10);
+ tqlayout->addWidget(class_tree, 10);
connect( class_combo, TQT_SIGNAL(activated(const TQString&)),
this, TQT_SLOT(slotClassComboChoice(const TQString&)) );
@@ -112,8 +112,8 @@ ClassToolDialog::ClassToolDialog( ClassViewPart *part )
this, TQT_SLOT(slotClose()) );
connect( access_combo, TQT_SIGNAL(activated(const TQString&)),
this, TQT_SLOT(slotAccessComboChoice(const TQString&)) );
- connect( parents_button, TQT_SIGNAL(clicked()), TQT_SLOT(viewParents()));
- connect( children_button, TQT_SIGNAL(clicked()), TQT_SLOT(viewChildren()));
+ connect( tqparents_button, TQT_SIGNAL(clicked()), TQT_SLOT(viewParents()));
+ connect( tqchildren_button, TQT_SIGNAL(clicked()), TQT_SLOT(viewChildren()));
connect( clients_button, TQT_SIGNAL(clicked()), TQT_SLOT(viewClients()));
connect( suppliers_button, TQT_SIGNAL(clicked()), TQT_SLOT(viewSuppliers()));
connect( methods_button, TQT_SIGNAL(clicked()), TQT_SLOT(viewMethods()));
@@ -170,7 +170,7 @@ void ClassToolDialog::viewNone()
}
/** View the parents of the current class. */
void ClassToolDialog::viewParents()
{
currentOperation = ViewParents;
@@ -178,7 +178,7 @@ void ClassToolDialog::viewParents()
}
/** View the children of the current class. */
void ClassToolDialog::viewChildren()
{
currentOperation = ViewChildren;
@@ -202,7 +202,7 @@ void ClassToolDialog::viewSuppliers()
}
/** View methods in this class and parents. */
void ClassToolDialog::viewMethods()
{
currentOperation = ViewMethods;
@@ -210,7 +210,7 @@ void ClassToolDialog::viewMethods()
}
/** View attributes in this class and parents. */
void ClassToolDialog::viewAttributes()
{
currentOperation = ViewAttributes;
@@ -283,11 +283,11 @@ void ClassToolDialog::updateCaptionAndButtons()
switch (currentOperation)
{
case ViewParents:
- button = parents_button;
+ button = tqparents_button;
caption = i18n("Parents");
break;
case ViewChildren:
- button = children_button;
+ button = tqchildren_button;
caption = i18n("Children");
break;
case ViewClients:
@@ -300,11 +300,11 @@ void ClassToolDialog::updateCaptionAndButtons()
break;
case ViewMethods:
button = methods_button;
- caption = i18n("%1 Methods").arg(access_combo->currentText());
+ caption = i18n("%1 Methods").tqarg(access_combo->currentText());
break;
case ViewAttributes:
button = attributes_button;
- caption = i18n("%1 Attributes").arg(access_combo->currentText());
+ caption = i18n("%1 Attributes").tqarg(access_combo->currentText());
break;
default:
button = 0;
@@ -312,8 +312,8 @@ void ClassToolDialog::updateCaptionAndButtons()
break;
}
- parents_button->setOn(false);
- children_button->setOn(false);
+ tqparents_button->setOn(false);
+ tqchildren_button->setOn(false);
clients_button->setOn(false);
suppliers_button->setOn(false);
methods_button->setOn(false);
@@ -321,7 +321,7 @@ void ClassToolDialog::updateCaptionAndButtons()
if (button) {
button->setOn(true);
- setCaption(i18n("%1 of Class %2").arg(caption).arg(currentClass->name()));
+ setCaption(i18n("%1 of Class %2").tqarg(caption).tqarg(currentClass->name()));
} else
setCaption(caption);
}
@@ -339,7 +339,7 @@ void ClassToolDialog::buildTree()
switch (currentOperation)
{
case ViewParents:
- class_tree->insertClassAndClasses(currentClass, currentClass->parents);
+ class_tree->insertClassAndClasses(currentClass, currentClass->tqparents);
break;
case ViewChildren:
{
@@ -170,7 +170,7 @@ void ClassToolDialog::viewNone()
}
-/** View the parents of the current class. */
+/** View the tqparents of the current class. */
void ClassToolDialog::viewParents()
{
@@ -178,7 +178,7 @@ void ClassToolDialog::viewParents()
}
-/** View the children of the current class. */
+/** View the tqchildren of the current class. */
void ClassToolDialog::viewChildren()
{
@@ -202,7 +202,7 @@ void ClassToolDialog::viewSuppliers()
}
-/** View methods in this class and parents. */
+/** View methods in this class and tqparents. */
void ClassToolDialog::viewMethods()
{
@@ -210,7 +210,7 @@ void ClassToolDialog::viewMethods()
}
-/** View attributes in this class and parents. */
+/** View attributes in this class and tqparents. */
void ClassToolDialog::viewAttributes()
{